/**
 * Wavy Colour Banner
 */
'use strict';

import ColourBannerManager from './colour-banner-manager.js';

var colourBannerManager;

function getManager() {
    if (!colourBannerManager) {
        colourBannerManager = new ColourBannerManager();
    }

    return colourBannerManager;
}

/**
 * Find all marked-up elements and create banners for them.
 */
document.addEventListener("DOMContentLoaded", function() {
    var manager = getManager();

    const elements = document.querySelectorAll('[data-wavy-colour-banner]');
    elements.forEach(function(element) {
        var definitionRaw = element.dataset.wavyColourBanner;
        var definition = null;

        if (definitionRaw) {
            definition = JSON.parse(definitionRaw);
        }

        definition = manager.sanitiseDefinition(definition);

        if (element.dataset.wcbSlide) {
            var duration = parseInt(element.dataset.wcbSlide);
            if( duration > 0 ) {
                definition.slideIntro.duration = duration;
                definition.slideIntro.isEnabled = true;
            }
            else {
                definition.slideIntro.isEnabled = false;
            }
        }

        if (element.dataset.wcbFade) {
            var duration = parseInt(element.dataset.wcbFade);
            if( duration > 0 ) {
                definition.fadeIntro.duration = duration;
                definition.fadeIntro.isEnabled = true;
            }
            else {
                definition.fadeIntro.isEnabled = false;
            }
        }

        if (element.dataset.wcbPrimaryColour) {
            definition.primaryColour = element.dataset.wcbPrimaryColour;
        }

        // definition.primaryColour = 'purple';

        create(
            element,
            definition
        );
    });
});


/**
 * Create instance(s) of wavy colour banners and start animating.
 * 
 * elementOrSelector (string or element)
 * Can be a CSS selector string or a DOM element object.
 * If it's a CSS selector string, multiple banners might be created.
 * If it's a DOM element, only a single banner will be created.
 * Each banner is created and then inserted as the element's first child.
 * 
 * definition (optional, object)
 * An optional banner definition object. If it's not specified, the default
 * wispy definition is used. If a partial definition is specified then
 * missing properties are populated from the default definition.
 * 
 */
export function create(elementOrSelector, definition = null, options = null) {
    var manager = getManager();
    var actualDefinition = manager.sanitiseDefinition(definition);

    if ((elementOrSelector instanceof HTMLElement) && (typeof elementOrSelector.ownerDocument != 'undefined')) {
        colourBannerManager.create(elementOrSelector, actualDefinition);
    } else {
        const elements = document.querySelectorAll(elementOrSelector);
        elements.forEach(function(element) {
            colourBannerManager.create(element, actualDefinition);
        });
    }
}