const path = require('path');
const TerserPlugin = require("terser-webpack-plugin");

module.exports = {
    entry: './src/index.js',
    mode: 'development',
    devtool: 'inline-source-map',
    output: {
        filename: 'wavy-colour-banner.js',
        path: path.resolve(__dirname, 'build'),
        library: {
            type: 'var',
            name: 'WavyColourBanner'
        }
    },
    resolve: {
        extensions: ['*', '.js']
    },
    module: {
        rules: [{
            test: /\.(js)$/,
            exclude: /node_modules/,
            use: "babel-loader",
        }]
    },
    devServer: {
        static: {
            directory: path.join(__dirname, 'build'),
        },
        compress: false,
        port: 9000,
        hot: true,
        client: {
            overlay: true,
            progress: true,
        },
        allowedHosts: 'all'
    },
    optimization: {
        minimize: true,
        minimizer: [new TerserPlugin({
            terserOptions: {
                compress: {
                    drop_console: true
                }
            }
        })],
    },
};